/*
 * This file is part of queso.
 *
 * Copyright © 2020 Canek Peláez Valdés
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 *    Canek Peláez Valdés <canek@ciencias.unam.mx>
 */

namespace Queso {

    /**
     * Class for video source settings dialogs.
     */
    [GtkTemplate (ui = "/mx/unam/Queso/video-source-settings-dialog.ui")]
    public class VideoSourceSettingsDialog : Gtk.Dialog {

        private Devices devices;
        private V4LControlManager v4lmgr;
        private Gee.ArrayList<V4LControlWidget> v4lwidgets;

        [GtkChild]
        private Gtk.ComboBoxText video_source_combo;

        [GtkChild]
        private Gtk.Grid vs_grid;

        public VideoSourceSettingsDialog(ApplicationWindow window,
                                         Devices devices) {
            GLib.Object(use_header_bar: 1);
            transient_for = window;
            this.devices = devices;

            if (devices == null)
                return;
            foreach (var device in devices.video_devices) {
                video_source_combo.append_text(device.name);
            }
            video_source_combo.active_id = devices.video_device.name;
            var dp = devices.video_device.device_path;
            if (dp == Devices.DEV_NULL) {
                var label = new Gtk.Label("No settings available for\n" +
                                          devices.video_device.name);
                vs_grid.attach(label, 0, 0, 1, 1);
                label.margin = 48;
                return;
            }

            v4lwidgets = new Gee.ArrayList<V4LControlWidget>();
            int row = 0;
            v4lmgr = new V4LControlManager(dp);
            for (int i = 0; i < v4lmgr.size; i++) {
                unowned V4LControl v4lctrl = v4lmgr.nth_control(i);
                var v4lwidget = new V4LControlWidget(v4lctrl);
                v4lwidgets.add(v4lwidget);
                vs_grid.attach(v4lwidget.label, 0, row, 2, 1);
                vs_grid.attach(v4lwidget.widget, 2, row++, 2, 1);
            }
        }

        [GtkCallback]
        private void on_close_clicked() {
            this.close();
        }

        [GtkCallback]
        private void on_video_source_combo_changed() {
        }
    }
}
